%define subrel	3

Summary:	Program that wraps normal socket connections with SSL/TLS
Name:		stunnel
Version:	4.56
Release:	%mkrel 3
License:	GPLv2+
Group:		System/Servers
URL:		http://www.stunnel.org/
Source0:	http://www.stunnel.org/downloads/%{name}-%{version}.tar.gz
Source1:	http://www.stunnel.org/downloads/%{name}-%{version}.tar.gz.asc
Source2:	stunnel.service
Source3:	stunnel.tmpfiles
BuildRequires:	openssl-devel >= 0.9.5
BuildRequires:	tcp_wrappers-devel
Requires:	tcp_wrappers
Requires(post):	openssl
Obsoletes:	%mklibname %{name} 0
Obsoletes:	%mklibname %{name} -d
Obsoletes:	%mklibname %{name} -d -s

%description
The stunnel program is designed to work as SSL encryption wrapper between 
remote clients and local (inetd-startable) or remote servers. The concept is 
that having non-SSL aware daemons running on your system you can easily set 
them up to communicate with clients over secure SSL channels.

stunnel can be used to add SSL functionality to commonly used inetd daemons 
like POP-2, POP-3, and IMAP servers, to standalone daemons like NNTP, SMTP 
and HTTP, and in tunneling PPP over network sockets without changes to the 
source code.

%prep
%setup -q

# XXX don't install /var/lib/stunnel
perl -ni -e '/INSTALL.*-m 1770 -g nogroup.*stunnel$/ or print' tools/Makefile.am

%build
%configure2_5x \
    --with-threads=pthread \
    --with-ssl=%{_prefix} \
    --disable-static \
    --disable-fips \
    --enable-shared
%make pkglibdir=%{_libdir}

%install
rm -rf %{buildroot}

# (oe) hack... don't generate the pem file, and stunnel.conf
install -d %{buildroot}%{_sysconfdir}/%{name}
touch %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem

%makeinstall docdir=`pwd`/doc-to-install pkglibdir=%{buildroot}%{_libdir}

install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/stunnel.service

install -D -m 644 %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/stunnel.conf

mv %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf-sample \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

perl -pi \
    -e 's|chroot = .*|chroot = /run/stunnel|;' \
    -e 's|cert = .*|cert = /etc/pki/tls/certs/stunnel.pem|;' \
    -e 's|;key = .*|key = /etc/pki/tls/private/stunnel.pem|;' \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

# Move the translated man pages to the right subdirectories, and strip off the
# language suffixes.
for lang in fr pl ; do
    mkdir -p %{buildroot}%{_mandir}/${lang}/man8
    mv %{buildroot}%{_mandir}/man8/*.${lang}.8* %{buildroot}%{_mandir}/${lang}/man8/
    rename ".${lang}" "" %{buildroot}%{_mandir}/${lang}/man8/*
done

# cleanup
rm -f ./doc-to-install/INSTALL.W32 ./doc-to-install/COPYRIGHT.GPL
rm -f %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem
rm -f %{buildroot}%{_libdir}/libstunnel.la

%post
%_tmpfilescreate %{name}
%_create_ssl_certificate stunnel

%files
%doc doc-to-install/*
%{_bindir}/stunnel
%{_bindir}/stunnel3
%{_mandir}/man8/stunnel.8.*
%lang(fr) %{_mandir}/fr/man8/stunnel.8*
%lang(pl) %{_mandir}/pl/man8/stunnel.8*
%config(noreplace) %{_sysconfdir}/%{name}/stunnel.conf
%{_unitdir}/stunnel.service
%{_prefix}/lib/tmpfiles.d/stunnel.conf
%{_libdir}/libstunnel.so


%changelog
* Tue Apr 29 2014 guillomovitch <guillomovitch> 4.56-3.3.mga4
+ Revision: 618879
- disable FIPS support, as our openssl package doesn't support it (fix #11000)
- switch to pthread threading model to fix CVE-2014-0016

  + luigiwalser <luigiwalser>
    - create pidfile dir at package installation time

* Sat Oct 19 2013 umeabot <umeabot> 4.56-3.mga4
+ Revision: 530118
- Mageia 4 Mass Rebuild

* Fri Jul 19 2013 danf <danf> 4.56-2.mga4
+ Revision: 456234
- source man pages are now UTF-8, so don't convert them any more since
  it corrupts them
- license is actually GPLv2 or later, and don't bother including it in package

* Sun May 26 2013 blino <blino> 4.56-1.mga4
+ Revision: 428204
- 4.56

* Tue Mar 05 2013 guillomovitch <guillomovitch> 4.55-1.mga3
+ Revision: 401451
- new version

* Mon Jan 14 2013 umeabot <umeabot> 4.54-3.mga3
+ Revision: 383570
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 4.54-2.mga3
+ Revision: 341223
- Require openssl to fix post scriptlet

* Sat Jan 05 2013 luigiwalser <luigiwalser> 4.54-1.mga3
+ Revision: 338948
- 4.54
- fix source URLs

* Mon Sep 17 2012 guillomovitch <guillomovitch> 4.53-6.mga3
+ Revision: 295579
- no need for version in obsoletes tags
- chroot to /run/stunnel in default configuration
- convert /run/stunnel to tmpfs
- minor fixes to the systemd service

* Thu Sep 06 2012 luigiwalser <luigiwalser> 4.53-5.mga3
+ Revision: 288889
- fix syntax for obsoleting old library packages

* Wed Sep 05 2012 luigiwalser <luigiwalser> 4.53-4.mga3
+ Revision: 288622
- obsolete library package

* Mon Aug 20 2012 guillomovitch <guillomovitch> 4.53-3.mga3
+ Revision: 282639
- don't bother using library and devel subpackage, as there is no defined interface, and no include file available (#4223)

* Tue Aug 14 2012 guillomovitch <guillomovitch> 4.53-2.mga3
+ Revision: 281253
- add systemd support (Bit Twister <junk_no_spam@verizon.net>)
- mark the configuration file as configuration
- readd explicit lib package dependenncy

* Tue Aug 14 2012 guillomovitch <guillomovitch> 4.53-1.mga3
+ Revision: 281247
- new version
- spec cleanup
- drop useless patches
- drop static lib package
- use rpm-helper macros to generate ssl certificate

* Sun Jan 09 2011 blino <blino> 4.34-3.mga1
+ Revision: 3737
- remove old ldconfig scriptlets
- imported package stunnel

